package net.chrisrichardson.foodToGo.order;

import net.chrisrichardson.foodToGo.creditCardProcessing.*;


/*
 * Base class for those classes that initialize all the various
 * factories and repositories.
 * 
 * It uses the factory method pattern to create the implementation classes
 */
 
public abstract class BaseDomainConfigurator implements DomainConfigurator {

    public void configure() {
        TxnManagerFactory.setImplementation(makeDomainManager());
        OrderFactory.setImplementation(makeOrderFactory());
        OrderRepository.setImplementation(makeOrderRepository());
        PendingOrderRepository.setImplementation(makePendingOrderRepository());
        RestaurantRepository.setImplementation(makeRestaurantRepository());
        CreditCardProcessor.setImplementation(makeCreditCardProcessor());
    }

    protected abstract CreditCardProcessorImpl makeCreditCardProcessor();
    protected abstract RestaurantRepositoryImpl makeRestaurantRepository();
    protected abstract PendingOrderRepositoryImpl makePendingOrderRepository();
    protected abstract OrderRepositoryImpl makeOrderRepository();
    protected abstract OrderFactoryImpl makeOrderFactory();
    protected abstract TxnManagerFactoryImpl makeDomainManager();

}
