/* Copyright (c) 2002 Chris Richardson. All Rights Reserved */

package net.chrisrichardson.foodToGo.order;

import java.util.*;

import net.chrisrichardson.foodToGo.creditCardProcessing.*;
import net.chrisrichardson.foodToGo.order.*;
import net.chrisrichardson.foodToGo.util.*; 

/*
 * Contains data for the tests
 * It is used to create the JDO objects to insert into the database
 */
 
public class PendingOrderTestData extends TestData {

	static {
		// This is a bit of a hack
		loadObjectIds(PendingOrderTestData.class);
	}

	public static String ZIP1 = "94619";
	public static String ZIP2 = "94618";
	public static String BAD_ZIP = "45001";

	public static Address ADDRESS1 =
		new Address("1 somewhere", null, "Oakland", "CA", ZIP1);
	public static Address ADDRESS1A =
		new Address("2 somewhere", null, "Oakland", "CA", ZIP1);
	public static Address ADDRESS2 =
		new Address("1 somewhere", null, "Oakland", "CA", ZIP2);
	public static Address BAD_ADDRESS =
		new Address("1 somewhere", null, "Oakland", "CA", BAD_ZIP);

	public static String RESTAURANT_ID1;

	public static String RESTAURANT_ID1a;

	public static String RESTAURANT_ID2;

	private OpeningHours makeDefaultOpeningHours() {
		OpeningHours openingHours = new OpeningHours();
		Calendar c = Calendar.getInstance();
		c.clear();
		c.set(Calendar.HOUR_OF_DAY, 18);
		Date sixPM = c.getTime();
		c.set(Calendar.HOUR_OF_DAY, 23);
		Date elevenPM = c.getTime();

		System.out.println("sixPM = " + sixPM);
		System.out.println("elevenPM = " + elevenPM);

		TimeRange sixToEleven = new TimeRange(sixPM, elevenPM);
		openingHours.add(Calendar.SUNDAY, sixToEleven);
		openingHours.add(Calendar.MONDAY, sixToEleven);
		openingHours.add(Calendar.TUESDAY, sixToEleven);
		openingHours.add(Calendar.WEDNESDAY, sixToEleven);
		openingHours.add(Calendar.THURSDAY, sixToEleven);
		openingHours.add(Calendar.FRIDAY, sixToEleven);
		openingHours.add(Calendar.SATURDAY, sixToEleven);
		return openingHours;
	}

	public Restaurant restaurant1;

	public Restaurant restaurant1a;

	public Restaurant restaurant2;

	public static Date makeGoodDeliveryTime() {
		return getTimeTomorrow(20);
	}

	public Collection restaurants = new ArrayList();
	public Collection pendingOrders = new ArrayList();

	public static PaymentInformation PAYMENT_INFORMATION =
		new PaymentInformation(
			"VISA",
			"John Doe",
			"55555-777-777",
			1,
			2004,
			new Address("1 somestreet", null, "AnyTown", "CA", "56789"));

	// Here are the test cases for a modal class

	public PendingOrderTestData() {
		this(true);
	}

	public PendingOrderTestData(boolean create) {
		if (create)
			createTestData();
		else
			loadData();
		add(restaurant1);
		add(restaurant1a);
		add(restaurant2);
	}

	public void createTestData() {
		double chatPrice = 4.56;

		Collection menuItems = new ArrayList();
		menuItems.add(makeMenuItem(0, "Chicken Chaat", chatPrice));
		menuItems.add(makeMenuItem(1, "Bombay Potatoes", 7.89));

		restaurant1 =
			makeRestaurant("Ajanta", ZIP1, makeDefaultOpeningHours(), menuItems);

		save("RESTAURANT_ID1", RESTAURANT_ID1, restaurant1);

		// TODO - not setting backpointer

		MenuItem anotherMenuItem = makeMenuItem(0, "Chicken Chaat", chatPrice);
		Collection moreMenuItems = new ArrayList();
		moreMenuItems.add(anotherMenuItem);

		// TODO - not setting backpointer

		restaurant1a =
			makeRestaurant("PizzaPalace", ZIP1, makeDefaultOpeningHours(), moreMenuItems);

		save("RESTAURANT_ID1a", RESTAURANT_ID1a, restaurant1a);

		// TODO - not setting backpointer
		anotherMenuItem = makeMenuItem(0, "Chicken Chaat", chatPrice);
		moreMenuItems = new ArrayList();
		moreMenuItems.add(anotherMenuItem);

		restaurant2 =
			makeRestaurant("Cesars", ZIP2, makeDefaultOpeningHours(), moreMenuItems);

		save("RESTAURANT_ID2", RESTAURANT_ID2, restaurant2);

	}

	public void add(Restaurant restaurant) {
		restaurants.add(restaurant);
	}

	public void add(PendingOrder order) {
		pendingOrders.add(order);
	}

	public static Date getTimeTomorrow(int hour) {
		Calendar c = Calendar.getInstance();
		c.add(Calendar.DAY_OF_MONTH, 1);
		c.set(Calendar.HOUR_OF_DAY, hour);
		Date during = c.getTime();
		return during;
	}

	public Collection getAllObjects() {
		ArrayList all = new ArrayList();
		all.addAll(restaurants);
		all.addAll(pendingOrders);
		return all;
	}

	public static int[] getTEST_QUANTITIES() {
		return new int[] { 5, 5 };
	}

	public static int[] getZERO_QUANTITIES() {
		return new int[] { 0, 0 };
	}

	protected Restaurant makeRestaurant(
		String name,
		String zipCode,
		OpeningHours openingHours,
		Collection menuItems) {
		return new Restaurant(
			name,
			zipCode,
			openingHours,
			menuItems);
	}

	protected MenuItem makeMenuItem(int index, String description, double price) {
		return new MenuItem(index, description, price);
	}

	protected void loadData() {
	}

}