package net.chrisrichardson.foodToGo.order.jdoImpl;

import java.io.*;
import java.util.*;

import javax.jdo.*;
import junit.framework.*;

/*
 * Helper class for writing JDO test cases
 * Provides access to the JDO PersistenceManager in a two-tier environment
 */
 
public class JDOTestCaseHelper {

    protected PersistenceManager pm;

    public void setUp() throws IOException {
		PersistenceManagerFactory pmf = getPMF();
        pm = pmf.getPersistenceManager();
        begin();
        PMRegistry.setPM(pm);
    }

	public static PersistenceManagerFactory getPMF() throws FileNotFoundException, IOException {
		Properties p = getProperties();
		PersistenceManagerFactory pmf = JDOHelper.getPersistenceManagerFactory(p);
		return pmf;
	}

    public void tearDown()  {
        commit();
        PMRegistry.setPM(null);
        pm.close();
    }

    public void begin() {
        pm.currentTransaction().begin();
    }

    public void commit() {
        pm.currentTransaction().commit();
    }
    
    public void checkpoint() {
        commit();
        begin();
    }
    protected static Properties getProperties() throws FileNotFoundException, IOException {
        Properties localProperties = getProperties("properties/local.properties");
        if (localProperties.containsKey("use.jdoGenie"))
            return getJDOProperties("/foodToGo.jdogenie");
        if (localProperties.containsKey("use.kodo"))
            return getJDOProperties("/kodo.properties");
        Assert.fail("don't know which JDO vendor");
        return null;
    }

    protected static Properties getProperties(String fileName)
        throws FileNotFoundException, IOException {
        Properties p = new Properties();
        InputStream fis = null;
        try {
            fis = new FileInputStream(fileName);
            p.load(fis);
        } finally {
            if (fis != null)
                fis.close();
        }
        return p;
    }

    protected static Properties getJDOProperties(String fileName)
        throws FileNotFoundException, IOException {
        Properties p = new Properties();
        InputStream fis = null;
        try {
            fis = JDOTestCaseHelper.class.getResourceAsStream(fileName);
            p.load(fis);
        } finally {
            if (fis != null)
                fis.close();
        }
        return p;
    }

    public PersistenceManager getPm() {
        return pm;
    }


}
