/* Copyright (c) 2002 Chris Richardson. All Rights Reserved */


package net.chrisrichardson.foodToGo.orderService.impl;

import net.chrisrichardson.foodToGo.order.*;
import net.chrisrichardson.foodToGo.orderService.values.*;
import net.chrisrichardson.foodToGo.util.*;

import java.util.*;

/*
 * Creates the PendingOrderValue from the PendingOrder object
 */
 
public class PendingOrderValueFactory {

    static PendingOrderValue makePendingOrderValue(PendingOrder pendingOrder) {
        return new PendingOrderValue(pendingOrder.getDeliveryAddress(),
                pendingOrder.getDeliveryDate(),
                makeRestaurantValue(pendingOrder.getRestaurant()),
                makePendingOrderLineItemValueCollection(pendingOrder.getLineItems()),
                pendingOrder.getPaymentInformation(),
                pendingOrder.getSubtotal(),
                pendingOrder.getDeliveryCharges(),
                pendingOrder.getSalesTax(),
                pendingOrder.getTotal());
    }

    static PendingOrderLineItemValueCollection makePendingOrderLineItemValueCollection(PendingOrderLineItemCollection lineItems) {
        if (lineItems == null) return null;

        PendingOrderLineItemValueCollection result = new PendingOrderLineItemValueCollection();
        for (Iterator iterator = lineItems.iterator(); iterator.hasNext();) {
            PendingOrderLineItem lineItem = (PendingOrderLineItem) iterator.next();
            result.add(new PendingOrderLineItemValue(makeMenuItemValue(lineItem.getMenuItem()), lineItem.getQuantity()));
        }
        return result;
    }

    static MenuItemValue makeMenuItemValue(MenuItem mi) {
        return new MenuItemValue(RestaurantRepository.getObjectId(mi), mi.getName(), mi.getPrice());
    }

    static private RestaurantValue makeRestaurantValue(Restaurant restaurant) {
        if (restaurant == null) 
            return null;
        else
            return new RestaurantValue(RestaurantRepository.getObjectId(restaurant), restaurant.getName());
    }
}
