package net.chrisrichardson.foodToGo.util;

import java.io.*;
import java.util.*;

/*
 * Reads a configuration file specifying classNames and other properties
 */

public class BaseConfigurationFactory {

	private Properties properties = new Properties();
	private ClassLoader classLoader;
	private Class type;

	protected BaseConfigurationFactory(String name, Class type) {
		this.type = type;
		this.classLoader = type.getClassLoader();
		loadPropertiesFile(name);
	}

	private void loadPropertiesFile(String name) {
		InputStream is = null;
		try {
			is = type.getResourceAsStream(name);
			properties.load(is);
		} catch (IOException e) {
			e.toString();
			throw new RuntimeException(e.getMessage());
		} finally {
			if (is != null)
				try {
					is.close();
				} catch (IOException e) {
				}
		}
	}

	/*
	 * Instantiate the class specified by the property
	 */

	public Object newInstance(String name, Class expectedType) {
		try {
			Object o = forName(name).newInstance();
			if (!expectedType.isInstance(o)) {
				Class gotType = o.getClass();
				//                System.out.println("Expected classloader " + expectedType.getClassLoader());
				//                System.out.println("Expected classloader parent" + expectedType.getClassLoader().getParent());
				//                System.out.println("Found classloader " + gotType.getClassLoader());
				//                System.out.println("Found classloader parent" + gotType.getClassLoader().getParent());
				//                Class[] interfaces = gotType.getSuperclass().getInterfaces();
				//                for (int i = 0; i < interfaces.length; i++) {
				//                    System.out.println("Interface: " + interfaces[i]);
				//                    System.out.println("Interface: " + interfaces[i].getClassLoader());
				//				}
				throw new RuntimeException(
					"Not of right type: wanted " + expectedType + ", but got " + gotType);
			}
			return o;
		} catch (InstantiationException e) {
			e.toString();
			throw new RuntimeException(e.getMessage());
		} catch (IllegalAccessException e) {
			e.toString();
			throw new RuntimeException(e.getMessage());
		}
	}

	/*
	 * Finds the class specified by the property
	 */

	public Class forName(String name) {
		try {
			String className = properties.getProperty(name);
			Class theClass = Class.forName(className, true, classLoader);
			return theClass;
		} catch (ClassNotFoundException e) {
			e.toString();
			throw new RuntimeException(e.getMessage());
		}
	}

	public String getProperty(String name) {
		return properties.getProperty(name);
	}

}
