/* Copyright (c) 2002 Chris Richardson. All Rights Reserved */

package net.chrisrichardson.foodToGo.util;

import java.io.*;
import java.util.*;

public class BasePagedCollection implements Serializable {
    int totalSize;
    int pageSize;
    int startingIndex;
    Collection items;

    public BasePagedCollection(
        Collection items,
        int startingIndex,
        int totalSize,
        int pageSize) {
        this.pageSize = pageSize;
        this.totalSize = totalSize;
        this.startingIndex = startingIndex;
        this.items = items;
    }

    public int getPageSize() {
        return pageSize;
    }

    public int getStartingIndex() {
        return startingIndex;
    }

    public boolean isEmpty() {
        return items.isEmpty();
    }

    public int getTotalSize() {
        return totalSize;
    }

    public boolean isFirstPage() {
        return startingIndex == 1;
    }

    public boolean isLastPage() {
        return startingIndex >= totalSize - pageSize;
    }

    public int getPreviousPageIndex() {
        return startingIndex - pageSize;
    }

    public int getNextPageIndex() {
        return startingIndex + pageSize;
    }

    public Iterator iterator() {
        return items.iterator();
    }

    public Collection getItems() {
        return items;
    }

}
