-- Drop the tables whose names begin with FTGO_
SET feedback OFF heading OFF termout OFF

spool ../../build/temp/drop_tables.SQL;

select 'DROP TABLE ' || table_name || ' CASCADE CONSTRAINTS;'
   from sys.all_tables
   where table_name like 'FTGO_%' or table_name like 'JDO%'  AND owner=user;

spool off;

SET feedback ON heading ON termout ON

@../../build/temp/drop_tables.SQL

drop sequence FTGO_UNIQUE_ID_SEQUENCE;

-- Your stuff goes here

create sequence FTGO_UNIQUE_ID_SEQUENCE;

CREATE TABLE FTGO_RESTAURANT(
    RESTAURANT_ID NUMBER(10) NOT NULL,
    NAME VARCHAR2(100) NOT NULL,
    OPEN_1 NUMBER(10),
    CLOSE_1 NUMBER(10),
    OPEN_2 NUMBER(10),
    CLOSE_2 NUMBER(10),
    OPEN_3 NUMBER(10),
    CLOSE_3 NUMBER(10),
    OPEN_4 NUMBER(10),
    CLOSE_4 NUMBER(10),
    OPEN_5 NUMBER(10),
    CLOSE_5 NUMBER(10),
    OPEN_6 NUMBER(10),
    CLOSE_6 NUMBER(10),
    OPEN_7 NUMBER(10),
    CLOSE_7 NUMBER(10),
    CONSTRAINT FTGO_RESTAURANT_PK
        PRIMARY KEY(RESTAURANT_ID)
    );

CREATE TABLE FTGO_ZIPCODE(
    ZIPCODE VARCHAR2(5) NOT NULL,
    CONSTRAINT FTGO_ZIPCODE_PK
        PRIMARY KEY(ZIPCODE)
    );

CREATE TABLE FTGO_RESTAURANT_ZIPCODE(
    RESTAURANT_ZIPCODE_ID NUMBER(10) NOT NULL,
    RESTAURANT_ID NUMBER(10) NOT NULL,
    ZIPCODE VARCHAR2(5) NOT NULL,
    CONSTRAINT FTGO_REST_ZIPCODE_PK
        PRIMARY KEY(RESTAURANT_ZIPCODE_ID),
    CONSTRAINT FTGO_REST_ZIPCODE_REST_ID
        FOREIGN KEY(RESTAURANT_ID)
        REFERENCES FTGO_RESTAURANT(RESTAURANT_ID),
    CONSTRAINT FTGO_REST_ZIPCODE_ZIPCODE
        FOREIGN KEY(ZIPCODE)
        REFERENCES FTGO_ZIPCODE(ZIPCODE)
    );

CREATE TABLE FTGO_MENU_ITEM(
    MENU_ITEM_ID NUMBER(10) NOT NULL,
    RESTAURANT_ID NUMBER(10) NOT NULL,
    MENU_ITEM_INDEX NUMBER(10) NOT NULL,
    NAME VARCHAR2(50) NOT NULL,
    PRICE NUMBER(5, 2) NOT NULL,
    CONSTRAINT FTGO_MENU_ITEM
        PRIMARY KEY(MENU_ITEM_ID),
    CONSTRAINT FTGO_MENU_ITEM_RESTAURANT_FK
        FOREIGN KEY(RESTAURANT_ID)
        REFERENCES FTGO_RESTAURANT(RESTAURANT_ID));

CREATE TABLE FTGO_ORDER_STATUS (
    STATUS VARCHAR2(10),
    DESCRIPTION VARCHAR2(10),
    CONSTRAINT FTGO_ORDER_STATUS_PK
        PRIMARY KEY(STATUS)
);

CREATE TABLE FTGO_ORDER (
    ORDER_ID NUMBER(10) NOT NULL,
    ORDER_EXT_ID NUMBER(10),
    STATUS VARCHAR2(10),
    RESTAURANT_ID NUMBER(10), -- Jboss NOT NULL
    DELIVERY_STREET1 VARCHAR2(50) NOT NULL,
    DELIVERY_STREET2 VARCHAR2(50),
    DELIVERY_CITY VARCHAR2(50) NOT NULL,
    DELIVERY_STATE VARCHAR2(2) NOT NULL,
    DELIVERY_ZIP VARCHAR2(10) NOT NULL,
    DELIVERY_TIME DATE NOT NULL,
    CONSTRAINT FTGO_ORDER_PK
        PRIMARY KEY(ORDER_ID),
    CONSTRAINT FTGO_ORDER_EXT_ID_UNQ
        UNIQUE(ORDER_EXT_ID),
    CONSTRAINT FTGO_ORDER_RESTAURANT_FK
        FOREIGN KEY(RESTAURANT_ID)
        REFERENCES FTGO_RESTAURANT(RESTAURANT_ID)
        DEFERRABLE INITIALLY DEFERRED,
    CONSTRAINT FTGO_ORDER_STATUS_FK
        FOREIGN KEY(STATUS)
        REFERENCES FTGO_ORDER_STATUS(STATUS)
);


CREATE TABLE FTGO_ORDER_LINE_ITEM (
    ORDER_LINE_ITEM_ID NUMBER(10) NOT  NULL,
    QUANTITY NUMBER(10) NOT NULL,
    NAME VARCHAR2(50) NOT NULL,
    PRICE NUMBER(5, 2) NOT NULL,
    EXTENDED_PRICE NUMBER(5, 2) NOT NULL,
    ORDER_ID NUMBER(10), -- Jboss NOT NULL
    MENU_ITEM_ID NUMBER(10), -- Jboss NOT NULL
    CONSTRAINT FTGO_ORDER_LINE_ITEM_PK
        PRIMARY KEY(ORDER_LINE_ITEM_ID),
    CONSTRAINT FTGO_ORDER_LINE_ITEM_MENITM_FK
        FOREIGN KEY(MENU_ITEM_ID)
        REFERENCES FTGO_MENU_ITEM(MENU_ITEM_ID)
        DEFERRABLE INITIALLY DEFERRED,
    CONSTRAINT FTGO_ORDER_LINE_ITEM_ORDER_FK
        FOREIGN KEY(ORDER_ID)
        REFERENCES FTGO_ORDER(ORDER_ID)
        DEFERRABLE INITIALLY DEFERRED
);

CREATE TABLE FTGO_PENDING_ORDER (
    PENDING_ORDER_ID NUMBER(10) NOT NULL,
    RESTAURANT_ID NUMBER(10),
    DELIVERY_STREET1 VARCHAR2(50),
    DELIVERY_STREET2 VARCHAR2(50),
    DELIVERY_CITY VARCHAR2(50),
    DELIVERY_STATE VARCHAR2(2),
    DELIVERY_ZIP VARCHAR2(10),
    DELIVERY_TIME DATE,
    STATE NUMBER(5) NOT NULL,
	PAYMENT_TYPE VARCHAR2(20),
	PAYMENT_NAME VARCHAR2(100),
	PAYMENT_NUMBER VARCHAR2(50),
	PAYMENT_MONTH NUMBER(4),
	PAYMENT_YEAR NUMBER(4),
    PAYMENT_STREET1 VARCHAR2(50),
    PAYMENT_STREET2 VARCHAR2(50),
    PAYMENT_CITY VARCHAR2(50),
    PAYMENT_STATE VARCHAR2(2),
    PAYMENT_ZIP VARCHAR2(10),
    CONSTRAINT FTGO_P_ORDER_PK
        PRIMARY KEY(PENDING_ORDER_ID),
    CONSTRAINT FTGO_P_ORDER_RESTAURANT_FK
        FOREIGN KEY(RESTAURANT_ID)
        REFERENCES FTGO_RESTAURANT(RESTAURANT_ID));


CREATE TABLE FTGO_PENDING_ORDER_LINE_ITEM (
    PENDING_ORDER_LINE_ITEM_ID NUMBER(10) NOT  NULL,
    QUANTITY NUMBER(10) NOT NULL,
    PENDING_ORDER_ID NUMBER(10), -- TODO would be nice if this was NULL
    LINE_ITEM_INDEX NUMBER(10) NOT NULL,
    MENU_ITEM_ID NUMBER(10), -- JBOSS NOT NULL,
    CONSTRAINT FTGO_P_ORDER_LINE_ITEM_PK
        PRIMARY KEY(PENDING_ORDER_LINE_ITEM_ID),
    CONSTRAINT FTGO_P_ORD_LINE_ITEM_MENITM_FK
        FOREIGN KEY(MENU_ITEM_ID)
        REFERENCES FTGO_MENU_ITEM(MENU_ITEM_ID),
    CONSTRAINT FTGO_P_ORD_LINE_ITEM_ORDER_FK
        FOREIGN KEY(PENDING_ORDER_ID)
        REFERENCES FTGO_PENDING_ORDER(PENDING_ORDER_ID)
        DEFERRABLE INITIALLY DEFERRED
);

create table jdo_keygen (
    table_name VARCHAR2(64) not null,
    last_used_id INTEGER not null,
    constraint pk_jdo_keygen primary key (table_name)
);

CREATE OR REPLACE TRIGGER FTGO_POL_TRIGGER
BEFORE INSERT ON FTGO_PENDING_ORDER_LINE_ITEM
 FOR EACH ROW 
declare
pk number(10);
begin
if :new.PENDING_ORDER_LINE_ITEM_ID is null then
  select FTGO_UNIQUE_ID_SEQUENCE.nextval into pk from dual ;
  :new.PENDING_ORDER_LINE_ITEM_ID := pk;
end if;
end;
/
CREATE OR REPLACE TRIGGER FTGO_REST_ZIP_TRIGGER
BEFORE INSERT ON FTGO_RESTAURANT_ZIPCODE
 FOR EACH ROW 
declare
pk number(10);
begin
if :new.RESTAURANT_ZIPCODE_ID is null then
  select FTGO_UNIQUE_ID_SEQUENCE.nextval into pk from dual ;
  :new.RESTAURANT_ZIPCODE_ID := pk;
end if;
end;

/

quit;

